"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.datatransfer.v1.transfer_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateTransferRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    SOURCE_ID_FIELD_NUMBER: builtins.int
    TARGET_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TRANSFORMATION_FIELD_NUMBER: builtins.int
    DATA_OBJECTS_FIELD_NUMBER: builtins.int
    source_id: builtins.str
    """Identifier of the source endpoint."""
    target_id: builtins.str
    """Identifier of the target endpoint."""
    description: builtins.str
    """Description of the transfer."""
    folder_id: builtins.str
    """ID of the folder to create the transfer in.

    To get the folder ID, make a
    [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    type: yandex.cloud.datatransfer.v1.transfer_pb2.TransferType.ValueType
    name: builtins.str
    """The transfer name. Must be unique within the folder."""
    @property
    def runtime(self) -> yandex.cloud.datatransfer.v1.transfer_pb2.Runtime: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Transfer labels as `key:value` pairs.

        For details about the concept, see [documentation]({{ api-url-prefix
        }}/resource-manager/concepts/labels).
        """

    @property
    def transformation(self) -> yandex.cloud.datatransfer.v1.transfer_pb2.Transformation: ...
    @property
    def data_objects(self) -> yandex.cloud.datatransfer.v1.transfer_pb2.DataObjects: ...
    def __init__(
        self,
        *,
        source_id: builtins.str = ...,
        target_id: builtins.str = ...,
        description: builtins.str = ...,
        folder_id: builtins.str = ...,
        runtime: yandex.cloud.datatransfer.v1.transfer_pb2.Runtime | None = ...,
        type: yandex.cloud.datatransfer.v1.transfer_pb2.TransferType.ValueType = ...,
        name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        transformation: yandex.cloud.datatransfer.v1.transfer_pb2.Transformation | None = ...,
        data_objects: yandex.cloud.datatransfer.v1.transfer_pb2.DataObjects | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_objects", b"data_objects", "runtime", b"runtime", "transformation", b"transformation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data_objects", b"data_objects", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "runtime", b"runtime", "source_id", b"source_id", "target_id", b"target_id", "transformation", b"transformation", "type", b"type"]) -> None: ...

global___CreateTransferRequest = CreateTransferRequest

@typing.final
class CreateTransferMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRANSFER_ID_FIELD_NUMBER: builtins.int
    transfer_id: builtins.str
    def __init__(
        self,
        *,
        transfer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["transfer_id", b"transfer_id"]) -> None: ...

global___CreateTransferMetadata = CreateTransferMetadata

@typing.final
class UpdateTransferRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TRANSFER_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TRANSFORMATION_FIELD_NUMBER: builtins.int
    DATA_OBJECTS_FIELD_NUMBER: builtins.int
    transfer_id: builtins.str
    """Identifier of the transfer to be updated."""
    description: builtins.str
    """The new description for the transfer."""
    name: builtins.str
    """The new transfer name. Must be unique within the folder."""
    @property
    def runtime(self) -> yandex.cloud.datatransfer.v1.transfer_pb2.Runtime: ...
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask specifying transfer fields to be updated. Semantics for this field is
        described here:
        <https://pkg.go.dev/google.golang.org/protobuf/types/known/fieldmaskpb#FieldMask>
        The only exception: if the repeated field is specified in the mask, then
        the new value replaces the old one instead of being appended to the old one.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Transfer labels as `key:value` pairs.

        For details about the concept, see [documentation]({{ api-url-prefix
        }}/resource-manager/concepts/labels).
        """

    @property
    def transformation(self) -> yandex.cloud.datatransfer.v1.transfer_pb2.Transformation: ...
    @property
    def data_objects(self) -> yandex.cloud.datatransfer.v1.transfer_pb2.DataObjects: ...
    def __init__(
        self,
        *,
        transfer_id: builtins.str = ...,
        description: builtins.str = ...,
        runtime: yandex.cloud.datatransfer.v1.transfer_pb2.Runtime | None = ...,
        name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        transformation: yandex.cloud.datatransfer.v1.transfer_pb2.Transformation | None = ...,
        data_objects: yandex.cloud.datatransfer.v1.transfer_pb2.DataObjects | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_objects", b"data_objects", "runtime", b"runtime", "transformation", b"transformation", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data_objects", b"data_objects", "description", b"description", "labels", b"labels", "name", b"name", "runtime", b"runtime", "transfer_id", b"transfer_id", "transformation", b"transformation", "update_mask", b"update_mask"]) -> None: ...

global___UpdateTransferRequest = UpdateTransferRequest

@typing.final
class UpdateTransferMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRANSFER_ID_FIELD_NUMBER: builtins.int
    transfer_id: builtins.str
    def __init__(
        self,
        *,
        transfer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["transfer_id", b"transfer_id"]) -> None: ...

global___UpdateTransferMetadata = UpdateTransferMetadata

@typing.final
class DeleteTransferRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRANSFER_ID_FIELD_NUMBER: builtins.int
    transfer_id: builtins.str
    """Identifier of the transfer to be deleted."""
    def __init__(
        self,
        *,
        transfer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["transfer_id", b"transfer_id"]) -> None: ...

global___DeleteTransferRequest = DeleteTransferRequest

@typing.final
class DeleteTransferMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRANSFER_ID_FIELD_NUMBER: builtins.int
    transfer_id: builtins.str
    def __init__(
        self,
        *,
        transfer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["transfer_id", b"transfer_id"]) -> None: ...

global___DeleteTransferMetadata = DeleteTransferMetadata

@typing.final
class ListTransfersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Identifier of the folder containing the transfers to be listed.

    To get the folder ID, make a
    [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of transfers to be sent in the response message. If the
    folder contains more transfers than `page_size`, `next_page_token` will be
    included
    in the response message. Include it into the subsequent `ListTransfersRequest`
    to
    fetch the next page. Defaults to `100` if not specified. The maximum allowed
    value
    for this field is `500`.
    """
    page_token: builtins.str
    """Opaque value identifying the transfers page to be fetched. Should be empty in
    the first `ListTransfersRequest`. Subsequent requests should have this field
    filled
    with the `next_page_token` from the previous `ListTransfersResponse`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListTransfersRequest = ListTransfersRequest

@typing.final
class ListTransfersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRANSFERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Opaque value identifying the next transfers page. This field is empty if there
    are no more transfers in the folder. Otherwise it is non-empty and should be
    included in the subsequent `ListTransfersRequest` to fetch the next transfers
    page.
    """
    @property
    def transfers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.datatransfer.v1.transfer_pb2.Transfer]:
        """The list of transfers. If there are more transfers in the folder, then
        `next_page_token` is a non-empty string to be included into the subsequent
        `ListTransfersRequest` to fetch the next transfers page.
        """

    def __init__(
        self,
        *,
        transfers: collections.abc.Iterable[yandex.cloud.datatransfer.v1.transfer_pb2.Transfer] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "transfers", b"transfers"]) -> None: ...

global___ListTransfersResponse = ListTransfersResponse

@typing.final
class GetTransferRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRANSFER_ID_FIELD_NUMBER: builtins.int
    transfer_id: builtins.str
    """Identifier of the transfer to be returned.

    To get the list of all available transfers, make a [List] request.
    """
    def __init__(
        self,
        *,
        transfer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["transfer_id", b"transfer_id"]) -> None: ...

global___GetTransferRequest = GetTransferRequest

@typing.final
class DeactivateTransferRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRANSFER_ID_FIELD_NUMBER: builtins.int
    transfer_id: builtins.str
    """Identifier of the transfer to be deactivated.

    To get the list of all available transfers, make a [List] request.
    """
    def __init__(
        self,
        *,
        transfer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["transfer_id", b"transfer_id"]) -> None: ...

global___DeactivateTransferRequest = DeactivateTransferRequest

@typing.final
class DeactivateTransferMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRANSFER_ID_FIELD_NUMBER: builtins.int
    transfer_id: builtins.str
    def __init__(
        self,
        *,
        transfer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["transfer_id", b"transfer_id"]) -> None: ...

global___DeactivateTransferMetadata = DeactivateTransferMetadata

@typing.final
class ActivateTransferRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRANSFER_ID_FIELD_NUMBER: builtins.int
    transfer_id: builtins.str
    """Identifier of the transfer to be activated.

    To get the list of all available transfers, make a [List] request.
    """
    def __init__(
        self,
        *,
        transfer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["transfer_id", b"transfer_id"]) -> None: ...

global___ActivateTransferRequest = ActivateTransferRequest

@typing.final
class ActivateTransferMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRANSFER_ID_FIELD_NUMBER: builtins.int
    transfer_id: builtins.str
    def __init__(
        self,
        *,
        transfer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["transfer_id", b"transfer_id"]) -> None: ...

global___ActivateTransferMetadata = ActivateTransferMetadata



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.kms.v1 import symmetric_crypto_service_pb2 as yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/kms/v1/symmetric_crypto_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SymmetricCryptoServiceStub(object):
    """--- Data plane for KMS symmetric cryptography operations

    Set of methods that perform symmetric encryption and decryption.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Encrypt = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricCryptoService/Encrypt',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricEncryptRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricEncryptResponse.FromString,
                _registered_method=True)
        self.Decrypt = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricCryptoService/Decrypt',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricDecryptRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricDecryptResponse.FromString,
                _registered_method=True)
        self.ReEncrypt = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricCryptoService/ReEncrypt',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricReEncryptRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricReEncryptResponse.FromString,
                _registered_method=True)
        self.GenerateDataKey = channel.unary_unary(
                '/yandex.cloud.kms.v1.SymmetricCryptoService/GenerateDataKey',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.GenerateDataKeyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.GenerateDataKeyResponse.FromString,
                _registered_method=True)


class SymmetricCryptoServiceServicer(object):
    """--- Data plane for KMS symmetric cryptography operations

    Set of methods that perform symmetric encryption and decryption.
    """

    def Encrypt(self, request, context):
        """Encrypts given plaintext with the specified key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Decrypt(self, request, context):
        """Decrypts the given ciphertext with the specified key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReEncrypt(self, request, context):
        """Re-encrypts a ciphertext with the specified KMS key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateDataKey(self, request, context):
        """Generates a new symmetric data encryption key (not a KMS key) and returns
        the generated key as plaintext and as ciphertext encrypted with the specified symmetric KMS key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SymmetricCryptoServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Encrypt': grpc.unary_unary_rpc_method_handler(
                    servicer.Encrypt,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricEncryptRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricEncryptResponse.SerializeToString,
            ),
            'Decrypt': grpc.unary_unary_rpc_method_handler(
                    servicer.Decrypt,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricDecryptRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricDecryptResponse.SerializeToString,
            ),
            'ReEncrypt': grpc.unary_unary_rpc_method_handler(
                    servicer.ReEncrypt,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricReEncryptRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricReEncryptResponse.SerializeToString,
            ),
            'GenerateDataKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateDataKey,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.GenerateDataKeyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.GenerateDataKeyResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.kms.v1.SymmetricCryptoService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.kms.v1.SymmetricCryptoService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SymmetricCryptoService(object):
    """--- Data plane for KMS symmetric cryptography operations

    Set of methods that perform symmetric encryption and decryption.
    """

    @staticmethod
    def Encrypt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.kms.v1.SymmetricCryptoService/Encrypt',
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricEncryptRequest.SerializeToString,
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricEncryptResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Decrypt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.kms.v1.SymmetricCryptoService/Decrypt',
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricDecryptRequest.SerializeToString,
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricDecryptResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReEncrypt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.kms.v1.SymmetricCryptoService/ReEncrypt',
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricReEncryptRequest.SerializeToString,
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.SymmetricReEncryptResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GenerateDataKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.kms.v1.SymmetricCryptoService/GenerateDataKey',
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.GenerateDataKeyRequest.SerializeToString,
            yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__crypto__service__pb2.GenerateDataKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.logging.v1.log_entry_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Workflow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Workflow._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Workflow._Status.ValueType  # 0
        CREATING: Workflow._Status.ValueType  # 1
        """Workflow is being created."""
        ACTIVE: Workflow._Status.ValueType  # 2
        """Workflow is ready for use."""
        UPDATING: Workflow._Status.ValueType  # 3
        """Workflow is being updated."""
        DELETING: Workflow._Status.ValueType  # 4
        """Workflow is being deleted."""
        ERROR: Workflow._Status.ValueType  # 5
        """Workflow failed. The only allowed action is delete."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Workflow.Status.ValueType  # 0
    CREATING: Workflow.Status.ValueType  # 1
    """Workflow is being created."""
    ACTIVE: Workflow.Status.ValueType  # 2
    """Workflow is ready for use."""
    UPDATING: Workflow.Status.ValueType  # 3
    """Workflow is being updated."""
    DELETING: Workflow.Status.ValueType  # 4
    """Workflow is being deleted."""
    ERROR: Workflow.Status.ValueType  # 5
    """Workflow failed. The only allowed action is delete."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    SPECIFICATION_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the Workflow. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the Workflow belongs to."""
    name: builtins.str
    """Name of the Workflow. The name is unique within the folder."""
    description: builtins.str
    """Description of the Workflow."""
    status: global___Workflow.Status.ValueType
    """Status of the Workflow."""
    network_id: builtins.str
    """ID of the VPC network Workflow will be executed in, in order to access private resources."""
    service_account_id: builtins.str
    """ID of the Service Account which will be used for resource access in Workflow execution."""
    @property
    def specification(self) -> global___WorkflowSpecification:
        """Specification of the Workflow"""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp for the Workflow."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Workflow labels as `key:value` pairs."""

    @property
    def log_options(self) -> global___LogOptions:
        """Options for logging from the Workflow."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        specification: global___WorkflowSpecification | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___Workflow.Status.ValueType = ...,
        log_options: global___LogOptions | None = ...,
        network_id: builtins.str = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "log_options", b"log_options", "specification", b"specification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "log_options", b"log_options", "name", b"name", "network_id", b"network_id", "service_account_id", b"service_account_id", "specification", b"specification", "status", b"status"]) -> None: ...

global___Workflow = Workflow

@typing.final
class WorkflowPreview(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the Workflow. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the Workflow belongs to."""
    name: builtins.str
    """Name of the Workflow. The name is unique within the folder."""
    description: builtins.str
    """Description of the Workflow."""
    status: global___Workflow.Status.ValueType
    """Status of the Workflow."""
    network_id: builtins.str
    """ID of the VPC network Workflow will be executed in, in order to access private resources."""
    service_account_id: builtins.str
    """ID of the Service Account which will be used for resources access in Workflow execution."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp for the Workflow."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Workflow labels as `key:value` pairs."""

    @property
    def log_options(self) -> global___LogOptions:
        """Options for logging from the Workflow."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___Workflow.Status.ValueType = ...,
        log_options: global___LogOptions | None = ...,
        network_id: builtins.str = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "log_options", b"log_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "log_options", b"log_options", "name", b"name", "network_id", b"network_id", "service_account_id", b"service_account_id", "status", b"status"]) -> None: ...

global___WorkflowPreview = WorkflowPreview

@typing.final
class WorkflowSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEC_YAML_FIELD_NUMBER: builtins.int
    spec_yaml: builtins.str
    """Workflow specification in YAML format."""
    def __init__(
        self,
        *,
        spec_yaml: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["spec", b"spec", "spec_yaml", b"spec_yaml"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["spec", b"spec", "spec_yaml", b"spec_yaml"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["spec", b"spec"]) -> typing.Literal["spec_yaml"] | None: ...

global___WorkflowSpecification = WorkflowSpecification

@typing.final
class LogOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    MIN_LEVEL_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    """Is logging from Workflow disabled."""
    log_group_id: builtins.str
    """ID of the logging group which should be used for Workflows logs."""
    folder_id: builtins.str
    """ID of the folder which default logging group should be used for Workflows."""
    min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType
    """Minimum logs level.

    See [LogLevel.Level] for details.
    """
    def __init__(
        self,
        *,
        disabled: builtins.bool = ...,
        log_group_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination", b"destination", "disabled", b"disabled", "folder_id", b"folder_id", "log_group_id", b"log_group_id", "min_level", b"min_level"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["log_group_id", "folder_id"] | None: ...

global___LogOptions = LogOptions



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datatransfer/v1/endpoint/metrika.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datatransfer/v1/endpoint/metrika.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1.endpoint import common_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/datatransfer/v1/endpoint/metrika.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x32yandex/cloud/datatransfer/v1/endpoint/common.proto\"h\n\rMetrikaStream\x12\x46\n\x04type\x18\x01 \x01(\x0e\x32\x38.yandex.cloud.datatransfer.v1.endpoint.MetrikaStreamType\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\"\xa9\x01\n\rMetrikaSource\x12\x13\n\x0b\x63ounter_ids\x18\x01 \x03(\x03\x12<\n\x05token\x18\x02 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.Secret\x12\x45\n\x07streams\x18\x03 \x03(\x0b\x32\x34.yandex.cloud.datatransfer.v1.endpoint.MetrikaStream*\x97\x01\n\x11MetrikaStreamType\x12#\n\x1fMETRIKA_STREAM_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18METRIKA_STREAM_TYPE_HITS\x10\x01\x12\x1e\n\x1aMETRIKA_STREAM_TYPE_VISITS\x10\x02\x12\x1f\n\x1bMETRIKA_STREAM_TYPE_HITS_V2\x10\x03\x42\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint.metrika_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint'
  _globals['_METRIKASTREAMTYPE']._serialized_start=425
  _globals['_METRIKASTREAMTYPE']._serialized_end=576
  _globals['_METRIKASTREAM']._serialized_start=146
  _globals['_METRIKASTREAM']._serialized_end=250
  _globals['_METRIKASOURCE']._serialized_start=253
  _globals['_METRIKASOURCE']._serialized_end=422
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/v1/budget_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/v1/budget_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.billing.v1 import budget_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_budget__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/billing/v1/budget_service.proto\x12\x17yandex.cloud.billing.v1\x1a\x1cgoogle/api/annotations.proto\x1a$yandex/cloud/billing/v1/budget.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\",\n\x10GetBudgetRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"|\n\x12ListBudgetsRequest\x12(\n\x12\x62illing_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"`\n\x13ListBudgetsResponse\x12\x30\n\x07\x62udgets\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.billing.v1.Budget\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc3\x02\n\x13\x43reateBudgetRequest\x12(\n\x12\x62illing_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x12\n\x04name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x43\n\x10\x63ost_budget_spec\x18\x03 \x01(\x0b\x32\'.yandex.cloud.billing.v1.CostBudgetSpecH\x00\x12I\n\x13\x65xpense_budget_spec\x18\x04 \x01(\x0b\x32*.yandex.cloud.billing.v1.ExpenseBudgetSpecH\x00\x12I\n\x13\x62\x61lance_budget_spec\x18\x05 \x01(\x0b\x32*.yandex.cloud.billing.v1.BalanceBudgetSpecH\x00\x42\x13\n\x0b\x62udget_spec\x12\x04\xc0\xc1\x31\x01\")\n\x14\x43reateBudgetMetadata\x12\x11\n\tbudget_id\x18\x01 \x01(\t2\xa2\x03\n\rBudgetService\x12s\n\x03Get\x12).yandex.cloud.billing.v1.GetBudgetRequest\x1a\x1f.yandex.cloud.billing.v1.Budget\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/billing/v1/budgets/{id}\x12~\n\x04List\x12+.yandex.cloud.billing.v1.ListBudgetsRequest\x1a,.yandex.cloud.billing.v1.ListBudgetsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/billing/v1/budgets\x12\x9b\x01\n\x06\x43reate\x12,.yandex.cloud.billing.v1.CreateBudgetRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*\x1e\n\x14\x43reateBudgetMetadata\x12\x06\x42udget\x82\xd3\xe4\x93\x02\x18\"\x13/billing/v1/budgets:\x01*Bb\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.v1.budget_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing'
  _globals['_GETBUDGETREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETBUDGETREQUEST'].fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTBUDGETSREQUEST'].fields_by_name['billing_account_id']._loaded_options = None
  _globals['_LISTBUDGETSREQUEST'].fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTBUDGETSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTBUDGETSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTBUDGETSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTBUDGETSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATEBUDGETREQUEST'].oneofs_by_name['budget_spec']._loaded_options = None
  _globals['_CREATEBUDGETREQUEST'].oneofs_by_name['budget_spec']._serialized_options = b'\300\3011\001'
  _globals['_CREATEBUDGETREQUEST'].fields_by_name['billing_account_id']._loaded_options = None
  _globals['_CREATEBUDGETREQUEST'].fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEBUDGETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEBUDGETREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001'
  _globals['_BUDGETSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_BUDGETSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\032\022\030/billing/v1/budgets/{id}'
  _globals['_BUDGETSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_BUDGETSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\025\022\023/billing/v1/budgets'
  _globals['_BUDGETSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_BUDGETSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreateBudgetMetadata\022\006Budget\202\323\344\223\002\030\"\023/billing/v1/budgets:\001*'
  _globals['_GETBUDGETREQUEST']._serialized_start=246
  _globals['_GETBUDGETREQUEST']._serialized_end=290
  _globals['_LISTBUDGETSREQUEST']._serialized_start=292
  _globals['_LISTBUDGETSREQUEST']._serialized_end=416
  _globals['_LISTBUDGETSRESPONSE']._serialized_start=418
  _globals['_LISTBUDGETSRESPONSE']._serialized_end=514
  _globals['_CREATEBUDGETREQUEST']._serialized_start=517
  _globals['_CREATEBUDGETREQUEST']._serialized_end=840
  _globals['_CREATEBUDGETMETADATA']._serialized_start=842
  _globals['_CREATEBUDGETMETADATA']._serialized_end=883
  _globals['_BUDGETSERVICE']._serialized_start=886
  _globals['_BUDGETSERVICE']._serialized_end=1304
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.billing.v1.budget_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetBudgetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the budget to return.
    To get the budget ID, use [BudgetService.List] request.
    """
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

global___GetBudgetRequest = GetBudgetRequest

@typing.final
class ListBudgetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    billing_account_id: builtins.str
    """ID of the billing account to list budgets corresponding to.
    To get the billing account ID, use [BillingAccountService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListBudgetsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListBudgetsResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        billing_account_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListBudgetsRequest = ListBudgetsRequest

@typing.final
class ListBudgetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUDGETS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListBudgetsRequest.page_size], use
    [next_page_token] as the value
    for the [ListBudgetsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def budgets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.v1.budget_pb2.Budget]:
        """List of budgets."""

    def __init__(
        self,
        *,
        budgets: collections.abc.Iterable[yandex.cloud.billing.v1.budget_pb2.Budget] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["budgets", b"budgets", "next_page_token", b"next_page_token"]) -> None: ...

global___ListBudgetsResponse = ListBudgetsResponse

@typing.final
class CreateBudgetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    COST_BUDGET_SPEC_FIELD_NUMBER: builtins.int
    EXPENSE_BUDGET_SPEC_FIELD_NUMBER: builtins.int
    BALANCE_BUDGET_SPEC_FIELD_NUMBER: builtins.int
    billing_account_id: builtins.str
    """ID of the billing account to list budgets corresponding to.
    To get the billing account ID, use [yandex.cloud.billing.v1.BillingAccountService.List] request.
    """
    name: builtins.str
    """Name of the budget."""
    @property
    def cost_budget_spec(self) -> yandex.cloud.billing.v1.budget_pb2.CostBudgetSpec:
        """Cost budget specification."""

    @property
    def expense_budget_spec(self) -> yandex.cloud.billing.v1.budget_pb2.ExpenseBudgetSpec:
        """Expense budget specification."""

    @property
    def balance_budget_spec(self) -> yandex.cloud.billing.v1.budget_pb2.BalanceBudgetSpec:
        """Balance budget specification."""

    def __init__(
        self,
        *,
        billing_account_id: builtins.str = ...,
        name: builtins.str = ...,
        cost_budget_spec: yandex.cloud.billing.v1.budget_pb2.CostBudgetSpec | None = ...,
        expense_budget_spec: yandex.cloud.billing.v1.budget_pb2.ExpenseBudgetSpec | None = ...,
        balance_budget_spec: yandex.cloud.billing.v1.budget_pb2.BalanceBudgetSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["balance_budget_spec", b"balance_budget_spec", "budget_spec", b"budget_spec", "cost_budget_spec", b"cost_budget_spec", "expense_budget_spec", b"expense_budget_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["balance_budget_spec", b"balance_budget_spec", "billing_account_id", b"billing_account_id", "budget_spec", b"budget_spec", "cost_budget_spec", b"cost_budget_spec", "expense_budget_spec", b"expense_budget_spec", "name", b"name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["budget_spec", b"budget_spec"]) -> typing.Literal["cost_budget_spec", "expense_budget_spec", "balance_budget_spec"] | None: ...

global___CreateBudgetRequest = CreateBudgetRequest

@typing.final
class CreateBudgetMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUDGET_ID_FIELD_NUMBER: builtins.int
    budget_id: builtins.str
    """ID of the budget."""
    def __init__(
        self,
        *,
        budget_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["budget_id", b"budget_id"]) -> None: ...

global___CreateBudgetMetadata = CreateBudgetMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/greenplum/v1/resource_preset.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/greenplum/v1/resource_preset.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/mdb/greenplum/v1/resource_preset.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\"\xa2\x02\n\x0eResourcePreset\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08zone_ids\x18\x02 \x03(\t\x12\x15\n\rdisk_type_ids\x18\n \x03(\t\x12\r\n\x05\x63ores\x18\x03 \x01(\x03\x12\x0e\n\x06memory\x18\x04 \x01(\x03\x12@\n\x04type\x18\x05 \x01(\x0e\x32\x32.yandex.cloud.mdb.greenplum.v1.ResourcePreset.Type\x12\x1a\n\x12host_count_divider\x18\x08 \x01(\x03\x12!\n\x19max_segment_in_host_count\x18\t \x01(\x03\"5\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MASTER\x10\x01\x12\x0b\n\x07SEGMENT\x10\x02J\x04\x08\x06\x10\x08\x42p\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.resource_preset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _globals['_RESOURCEPRESET']._serialized_start=87
  _globals['_RESOURCEPRESET']._serialized_end=377
  _globals['_RESOURCEPRESET_TYPE']._serialized_start=318
  _globals['_RESOURCEPRESET_TYPE']._serialized_end=371
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.tuning.v1.tuning_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class TuningServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Tune: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.TuningRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.ListTuningsRequest,
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.ListTuningsResponse,
    ]

    Describe: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.DescribeTuningRequest,
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.DescribeTuningResponse,
    ]

    Cancel: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.CancelTuningRequest,
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.CancelTuningResponse,
    ]

    GetMetricsUrl: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.GetMetricsUrlRequest,
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.GetMetricsUrlResponse,
    ]

    GetOptions: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.GetOptionsRequest,
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.GetOptionsResponse,
    ]

    ListErrors: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.ListErrorsRequest,
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.ListErrorsResponse,
    ]

class TuningServiceAsyncStub:
    Tune: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.TuningRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.ListTuningsRequest,
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.ListTuningsResponse,
    ]

    Describe: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.DescribeTuningRequest,
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.DescribeTuningResponse,
    ]

    Cancel: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.CancelTuningRequest,
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.CancelTuningResponse,
    ]

    GetMetricsUrl: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.GetMetricsUrlRequest,
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.GetMetricsUrlResponse,
    ]

    GetOptions: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.GetOptionsRequest,
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.GetOptionsResponse,
    ]

    ListErrors: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.ListErrorsRequest,
        yandex.cloud.ai.tuning.v1.tuning_service_pb2.ListErrorsResponse,
    ]

class TuningServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Tune(
        self,
        request: yandex.cloud.ai.tuning.v1.tuning_service_pb2.TuningRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.ai.tuning.v1.tuning_service_pb2.ListTuningsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.tuning.v1.tuning_service_pb2.ListTuningsResponse, collections.abc.Awaitable[yandex.cloud.ai.tuning.v1.tuning_service_pb2.ListTuningsResponse]]: ...

    @abc.abstractmethod
    def Describe(
        self,
        request: yandex.cloud.ai.tuning.v1.tuning_service_pb2.DescribeTuningRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.tuning.v1.tuning_service_pb2.DescribeTuningResponse, collections.abc.Awaitable[yandex.cloud.ai.tuning.v1.tuning_service_pb2.DescribeTuningResponse]]: ...

    @abc.abstractmethod
    def Cancel(
        self,
        request: yandex.cloud.ai.tuning.v1.tuning_service_pb2.CancelTuningRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.tuning.v1.tuning_service_pb2.CancelTuningResponse, collections.abc.Awaitable[yandex.cloud.ai.tuning.v1.tuning_service_pb2.CancelTuningResponse]]: ...

    @abc.abstractmethod
    def GetMetricsUrl(
        self,
        request: yandex.cloud.ai.tuning.v1.tuning_service_pb2.GetMetricsUrlRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.tuning.v1.tuning_service_pb2.GetMetricsUrlResponse, collections.abc.Awaitable[yandex.cloud.ai.tuning.v1.tuning_service_pb2.GetMetricsUrlResponse]]: ...

    @abc.abstractmethod
    def GetOptions(
        self,
        request: yandex.cloud.ai.tuning.v1.tuning_service_pb2.GetOptionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.tuning.v1.tuning_service_pb2.GetOptionsResponse, collections.abc.Awaitable[yandex.cloud.ai.tuning.v1.tuning_service_pb2.GetOptionsResponse]]: ...

    @abc.abstractmethod
    def ListErrors(
        self,
        request: yandex.cloud.ai.tuning.v1.tuning_service_pb2.ListErrorsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.tuning.v1.tuning_service_pb2.ListErrorsResponse, collections.abc.Awaitable[yandex.cloud.ai.tuning.v1.tuning_service_pb2.ListErrorsResponse]]: ...

def add_TuningServiceServicer_to_server(servicer: TuningServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Proxy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the proxy."""
    folder_id: builtins.str
    """ID of the folder that the proxy belongs to."""
    name: builtins.str
    """Name of the proxy."""
    description: builtins.str
    """Description of the proxy."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp for the proxy."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def target(self) -> global___Target:
        """MDB specific settings."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        target: global___Target | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "target", b"target"]) -> None: ...

global___Proxy = Proxy

@typing.final
class Target(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class PostgreSQL(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CLUSTER_ID_FIELD_NUMBER: builtins.int
        USER_FIELD_NUMBER: builtins.int
        PASSWORD_FIELD_NUMBER: builtins.int
        DB_FIELD_NUMBER: builtins.int
        ENDPOINT_FIELD_NUMBER: builtins.int
        cluster_id: builtins.str
        """Cluster identifier for postgresql."""
        user: builtins.str
        """PostgreSQL user."""
        password: builtins.str
        """PostgreSQL password, input only field."""
        db: builtins.str
        """PostgreSQL database name."""
        endpoint: builtins.str
        """PostgreSQL proxy-host for connection, output only field."""
        def __init__(
            self,
            *,
            cluster_id: builtins.str = ...,
            user: builtins.str = ...,
            password: builtins.str = ...,
            db: builtins.str = ...,
            endpoint: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "db", b"db", "endpoint", b"endpoint", "password", b"password", "user", b"user"]) -> None: ...

    @typing.final
    class ClickHouse(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CLUSTER_ID_FIELD_NUMBER: builtins.int
        USER_FIELD_NUMBER: builtins.int
        PASSWORD_FIELD_NUMBER: builtins.int
        DB_FIELD_NUMBER: builtins.int
        ENDPOINT_FIELD_NUMBER: builtins.int
        cluster_id: builtins.str
        """Cluster identifier for clickhouse."""
        user: builtins.str
        """Clickhouse user."""
        password: builtins.str
        """Clickhouse password, input only field."""
        db: builtins.str
        """Clickhouse database name."""
        endpoint: builtins.str
        """Clickhouse proxy-host for connection, output only field."""
        def __init__(
            self,
            *,
            cluster_id: builtins.str = ...,
            user: builtins.str = ...,
            password: builtins.str = ...,
            db: builtins.str = ...,
            endpoint: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "db", b"db", "endpoint", b"endpoint", "password", b"password", "user", b"user"]) -> None: ...

    CLICKHOUSE_FIELD_NUMBER: builtins.int
    POSTGRESQL_FIELD_NUMBER: builtins.int
    @property
    def clickhouse(self) -> global___Target.ClickHouse:
        """Clickhouse settings for proxy."""

    @property
    def postgresql(self) -> global___Target.PostgreSQL:
        """PostgreSQL settings for proxy."""

    def __init__(
        self,
        *,
        clickhouse: global___Target.ClickHouse | None = ...,
        postgresql: global___Target.PostgreSQL | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["clickhouse", b"clickhouse", "mdb", b"mdb", "postgresql", b"postgresql"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["clickhouse", b"clickhouse", "mdb", b"mdb", "postgresql", b"postgresql"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["mdb", b"mdb"]) -> typing.Literal["clickhouse", "postgresql"] | None: ...

global___Target = Target



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/v1/sku_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/v1/sku_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.billing.v1 import sku_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_sku__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/billing/v1/sku_service.proto\x12\x17yandex.cloud.billing.v1\x1a\x1cgoogle/api/annotations.proto\x1a!yandex/cloud/billing/v1/sku.proto\x1a\x1dyandex/cloud/validation.proto\"]\n\rGetSkuRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x16\n\x08\x63urrency\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x12\x62illing_account_id\x18\x03 \x01(\t\"\x9f\x01\n\x0fListSkusRequest\x12\x16\n\x08\x63urrency\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x12\x62illing_account_id\x18\x02 \x01(\t\x12\x1a\n\x06\x66ilter\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1d\n\tpage_size\x18\x04 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"W\n\x10ListSkusResponse\x12*\n\x04skus\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.billing.v1.Sku\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xef\x01\n\nSkuService\x12j\n\x03Get\x12&.yandex.cloud.billing.v1.GetSkuRequest\x1a\x1c.yandex.cloud.billing.v1.Sku\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/billing/v1/skus/{id}\x12u\n\x04List\x12(.yandex.cloud.billing.v1.ListSkusRequest\x1a).yandex.cloud.billing.v1.ListSkusResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/billing/v1/skusBb\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.v1.sku_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing'
  _globals['_GETSKUREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETSKUREQUEST'].fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETSKUREQUEST'].fields_by_name['currency']._loaded_options = None
  _globals['_GETSKUREQUEST'].fields_by_name['currency']._serialized_options = b'\350\3071\001'
  _globals['_LISTSKUSREQUEST'].fields_by_name['currency']._loaded_options = None
  _globals['_LISTSKUSREQUEST'].fields_by_name['currency']._serialized_options = b'\350\3071\001'
  _globals['_LISTSKUSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSKUSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTSKUSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSKUSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTSKUSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSKUSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_SKUSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_SKUSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\027\022\025/billing/v1/skus/{id}'
  _globals['_SKUSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_SKUSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\022\022\020/billing/v1/skus'
  _globals['_GETSKUREQUEST']._serialized_start=166
  _globals['_GETSKUREQUEST']._serialized_end=259
  _globals['_LISTSKUSREQUEST']._serialized_start=262
  _globals['_LISTSKUSREQUEST']._serialized_end=421
  _globals['_LISTSKUSRESPONSE']._serialized_start=423
  _globals['_LISTSKUSRESPONSE']._serialized_end=510
  _globals['_SKUSERVICE']._serialized_start=513
  _globals['_SKUSERVICE']._serialized_end=752
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/kms/v1/symmetric_crypto_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/kms/v1/symmetric_crypto_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.kms.v1 import symmetric_key_pb2 as yandex_dot_cloud_dot_kms_dot_v1_dot_symmetric__key__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/kms/v1/symmetric_crypto_service.proto\x12\x13yandex.cloud.kms.v1\x1a\x1cgoogle/api/annotations.proto\x1a\'yandex/cloud/kms/v1/symmetric_key.proto\x1a\x1dyandex/cloud/validation.proto\"\x9a\x01\n\x17SymmetricEncryptRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\nversion_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1f\n\x0b\x61\x61\x64_context\x18\x03 \x01(\x0c\x42\n\x8a\xc8\x31\x06<=8192\x12\"\n\tplaintext\x18\x04 \x01(\x0c\x42\x0f\xe8\xc7\x31\x01\x8a\xc8\x31\x07<=32768\"j\n\x18SymmetricEncryptResponse\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\nversion_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x12\n\nciphertext\x18\x03 \x01(\x0c\"r\n\x17SymmetricDecryptRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\x0b\x61\x61\x64_context\x18\x02 \x01(\x0c\x42\n\x8a\xc8\x31\x06<=8192\x12\x18\n\nciphertext\x18\x03 \x01(\x0c\x42\x04\xe8\xc7\x31\x01\"Q\n\x18SymmetricDecryptResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12\x11\n\tplaintext\x18\x03 \x01(\x0c\"\xcd\x01\n\x16GenerateDataKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\nversion_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1f\n\x0b\x61\x61\x64_context\x18\x03 \x01(\x0c\x42\n\x8a\xc8\x31\x06<=8192\x12>\n\rdata_key_spec\x18\x04 \x01(\x0e\x32\'.yandex.cloud.kms.v1.SymmetricAlgorithm\x12\x16\n\x0eskip_plaintext\x18\x05 \x01(\x08\"v\n\x17GenerateDataKeyResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x61ta_key_plaintext\x18\x03 \x01(\x0c\x12\x1b\n\x13\x64\x61ta_key_ciphertext\x18\x04 \x01(\x0c\"\xdf\x01\n\x19SymmetricReEncryptRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\nversion_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1f\n\x0b\x61\x61\x64_context\x18\x03 \x01(\x0c\x42\n\x8a\xc8\x31\x06<=8192\x12#\n\rsource_key_id\x18\x04 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12&\n\x12source_aad_context\x18\x05 \x01(\x0c\x42\n\x8a\xc8\x31\x06<=8192\x12\x18\n\nciphertext\x18\x06 \x01(\x0c\x42\x04\xe8\xc7\x31\x01\"\x86\x01\n\x1aSymmetricReEncryptResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12\x15\n\rsource_key_id\x18\x03 \x01(\t\x12\x19\n\x11source_version_id\x18\x04 \x01(\t\x12\x12\n\nciphertext\x18\x05 \x01(\x0c\x32\xfa\x04\n\x16SymmetricCryptoService\x12\x90\x01\n\x07\x45ncrypt\x12,.yandex.cloud.kms.v1.SymmetricEncryptRequest\x1a-.yandex.cloud.kms.v1.SymmetricEncryptResponse\"(\x82\xd3\xe4\x93\x02\"\"\x1d/kms/v1/keys/{key_id}:encrypt:\x01*\x12\x90\x01\n\x07\x44\x65\x63rypt\x12,.yandex.cloud.kms.v1.SymmetricDecryptRequest\x1a-.yandex.cloud.kms.v1.SymmetricDecryptResponse\"(\x82\xd3\xe4\x93\x02\"\"\x1d/kms/v1/keys/{key_id}:decrypt:\x01*\x12\x98\x01\n\tReEncrypt\x12..yandex.cloud.kms.v1.SymmetricReEncryptRequest\x1a/.yandex.cloud.kms.v1.SymmetricReEncryptResponse\"*\x82\xd3\xe4\x93\x02$\"\x1f/kms/v1/keys/{key_id}:reEncrypt:\x01*\x12\x9e\x01\n\x0fGenerateDataKey\x12+.yandex.cloud.kms.v1.GenerateDataKeyRequest\x1a,.yandex.cloud.kms.v1.GenerateDataKeyResponse\"0\x82\xd3\xe4\x93\x02*\"%/kms/v1/keys/{key_id}:generateDataKey:\x01*BV\n\x17yandex.cloud.api.kms.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1;kmsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.kms.v1.symmetric_crypto_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.kms.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1;kms'
  _globals['_SYMMETRICENCRYPTREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_SYMMETRICENCRYPTREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYMMETRICENCRYPTREQUEST'].fields_by_name['version_id']._loaded_options = None
  _globals['_SYMMETRICENCRYPTREQUEST'].fields_by_name['version_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_SYMMETRICENCRYPTREQUEST'].fields_by_name['aad_context']._loaded_options = None
  _globals['_SYMMETRICENCRYPTREQUEST'].fields_by_name['aad_context']._serialized_options = b'\212\3101\006<=8192'
  _globals['_SYMMETRICENCRYPTREQUEST'].fields_by_name['plaintext']._loaded_options = None
  _globals['_SYMMETRICENCRYPTREQUEST'].fields_by_name['plaintext']._serialized_options = b'\350\3071\001\212\3101\007<=32768'
  _globals['_SYMMETRICENCRYPTRESPONSE'].fields_by_name['key_id']._loaded_options = None
  _globals['_SYMMETRICENCRYPTRESPONSE'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYMMETRICENCRYPTRESPONSE'].fields_by_name['version_id']._loaded_options = None
  _globals['_SYMMETRICENCRYPTRESPONSE'].fields_by_name['version_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_SYMMETRICDECRYPTREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_SYMMETRICDECRYPTREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYMMETRICDECRYPTREQUEST'].fields_by_name['aad_context']._loaded_options = None
  _globals['_SYMMETRICDECRYPTREQUEST'].fields_by_name['aad_context']._serialized_options = b'\212\3101\006<=8192'
  _globals['_SYMMETRICDECRYPTREQUEST'].fields_by_name['ciphertext']._loaded_options = None
  _globals['_SYMMETRICDECRYPTREQUEST'].fields_by_name['ciphertext']._serialized_options = b'\350\3071\001'
  _globals['_GENERATEDATAKEYREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_GENERATEDATAKEYREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GENERATEDATAKEYREQUEST'].fields_by_name['version_id']._loaded_options = None
  _globals['_GENERATEDATAKEYREQUEST'].fields_by_name['version_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_GENERATEDATAKEYREQUEST'].fields_by_name['aad_context']._loaded_options = None
  _globals['_GENERATEDATAKEYREQUEST'].fields_by_name['aad_context']._serialized_options = b'\212\3101\006<=8192'
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['version_id']._loaded_options = None
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['version_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['aad_context']._loaded_options = None
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['aad_context']._serialized_options = b'\212\3101\006<=8192'
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['source_key_id']._loaded_options = None
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['source_key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['source_aad_context']._loaded_options = None
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['source_aad_context']._serialized_options = b'\212\3101\006<=8192'
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['ciphertext']._loaded_options = None
  _globals['_SYMMETRICREENCRYPTREQUEST'].fields_by_name['ciphertext']._serialized_options = b'\350\3071\001'
  _globals['_SYMMETRICCRYPTOSERVICE'].methods_by_name['Encrypt']._loaded_options = None
  _globals['_SYMMETRICCRYPTOSERVICE'].methods_by_name['Encrypt']._serialized_options = b'\202\323\344\223\002\"\"\035/kms/v1/keys/{key_id}:encrypt:\001*'
  _globals['_SYMMETRICCRYPTOSERVICE'].methods_by_name['Decrypt']._loaded_options = None
  _globals['_SYMMETRICCRYPTOSERVICE'].methods_by_name['Decrypt']._serialized_options = b'\202\323\344\223\002\"\"\035/kms/v1/keys/{key_id}:decrypt:\001*'
  _globals['_SYMMETRICCRYPTOSERVICE'].methods_by_name['ReEncrypt']._loaded_options = None
  _globals['_SYMMETRICCRYPTOSERVICE'].methods_by_name['ReEncrypt']._serialized_options = b'\202\323\344\223\002$\"\037/kms/v1/keys/{key_id}:reEncrypt:\001*'
  _globals['_SYMMETRICCRYPTOSERVICE'].methods_by_name['GenerateDataKey']._loaded_options = None
  _globals['_SYMMETRICCRYPTOSERVICE'].methods_by_name['GenerateDataKey']._serialized_options = b'\202\323\344\223\002*\"%/kms/v1/keys/{key_id}:generateDataKey:\001*'
  _globals['_SYMMETRICENCRYPTREQUEST']._serialized_start=178
  _globals['_SYMMETRICENCRYPTREQUEST']._serialized_end=332
  _globals['_SYMMETRICENCRYPTRESPONSE']._serialized_start=334
  _globals['_SYMMETRICENCRYPTRESPONSE']._serialized_end=440
  _globals['_SYMMETRICDECRYPTREQUEST']._serialized_start=442
  _globals['_SYMMETRICDECRYPTREQUEST']._serialized_end=556
  _globals['_SYMMETRICDECRYPTRESPONSE']._serialized_start=558
  _globals['_SYMMETRICDECRYPTRESPONSE']._serialized_end=639
  _globals['_GENERATEDATAKEYREQUEST']._serialized_start=642
  _globals['_GENERATEDATAKEYREQUEST']._serialized_end=847
  _globals['_GENERATEDATAKEYRESPONSE']._serialized_start=849
  _globals['_GENERATEDATAKEYRESPONSE']._serialized_end=967
  _globals['_SYMMETRICREENCRYPTREQUEST']._serialized_start=970
  _globals['_SYMMETRICREENCRYPTREQUEST']._serialized_end=1193
  _globals['_SYMMETRICREENCRYPTRESPONSE']._serialized_start=1196
  _globals['_SYMMETRICREENCRYPTRESPONSE']._serialized_end=1330
  _globals['_SYMMETRICCRYPTOSERVICE']._serialized_start=1333
  _globals['_SYMMETRICCRYPTOSERVICE']._serialized_end=1967
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/apploadbalancer/v1/target_group_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/apploadbalancer/v1/target_group_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.apploadbalancer.v1 import target_group_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_target__group__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/apploadbalancer/v1/target_group_service.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x32yandex/cloud/apploadbalancer/v1/target_group.proto\x1a\x1dyandex/cloud/validation.proto\"6\n\x15GetTargetGroupRequest\x12\x1d\n\x0ftarget_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8c\x01\n\x17ListTargetGroupsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"x\n\x18ListTargetGroupsResponse\x12\x43\n\rtarget_groups\x18\x01 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.TargetGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"9\n\x18\x44\x65leteTargetGroupRequest\x12\x1d\n\x0ftarget_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"4\n\x19\x44\x65leteTargetGroupMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"\xc6\x03\n\x18UpdateTargetGroupRequest\x12\x1d\n\x0ftarget_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9a\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x45.yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x38\n\x07targets\x18\x06 \x03(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.Target\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n\x19UpdateTargetGroupMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"\x8f\x03\n\x18\x43reateTargetGroupRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9a\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x45.yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x38\n\x07targets\x18\x05 \x03(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.Target\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n\x19\x43reateTargetGroupMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"t\n\x11\x41\x64\x64TargetsRequest\x12\x1d\n\x0ftarget_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12@\n\x07targets\x18\x02 \x03(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.TargetB\x06\x82\xc8\x31\x02>0\"-\n\x12\x41\x64\x64TargetsMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"w\n\x14RemoveTargetsRequest\x12\x1d\n\x0ftarget_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12@\n\x07targets\x18\x02 \x03(\x0b\x32\'.yandex.cloud.apploadbalancer.v1.TargetB\x06\x82\xc8\x31\x02>0\"0\n\x15RemoveTargetsMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"\x87\x01\n ListTargetGroupOperationsRequest\x12%\n\x0ftarget_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"s\n!ListTargetGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xee\x0c\n\x12TargetGroupService\x12\xa7\x01\n\x03Get\x12\x36.yandex.cloud.apploadbalancer.v1.GetTargetGroupRequest\x1a,.yandex.cloud.apploadbalancer.v1.TargetGroup\":\x82\xd3\xe4\x93\x02\x34\x12\x32/apploadbalancer/v1/targetGroups/{target_group_id}\x12\xa5\x01\n\x04List\x12\x38.yandex.cloud.apploadbalancer.v1.ListTargetGroupsRequest\x1a\x39.yandex.cloud.apploadbalancer.v1.ListTargetGroupsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /apploadbalancer/v1/targetGroups\x12\xbf\x01\n\x06\x43reate\x12\x39.yandex.cloud.apploadbalancer.v1.CreateTargetGroupRequest\x1a!.yandex.cloud.operation.Operation\"W\xb2\xd2*(\n\x19\x43reateTargetGroupMetadata\x12\x0bTargetGroup\x82\xd3\xe4\x93\x02%\" /apploadbalancer/v1/targetGroups:\x01*\x12\xd1\x01\n\x06Update\x12\x39.yandex.cloud.apploadbalancer.v1.UpdateTargetGroupRequest\x1a!.yandex.cloud.operation.Operation\"i\xb2\xd2*(\n\x19UpdateTargetGroupMetadata\x12\x0bTargetGroup\x82\xd3\xe4\x93\x02\x37\x32\x32/apploadbalancer/v1/targetGroups/{target_group_id}:\x01*\x12\xd8\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.apploadbalancer.v1.DeleteTargetGroupRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*2\n\x19\x44\x65leteTargetGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x34*2/apploadbalancer/v1/targetGroups/{target_group_id}\x12\xd2\x01\n\nAddTargets\x12\x32.yandex.cloud.apploadbalancer.v1.AddTargetsRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*!\n\x12\x41\x64\x64TargetsMetadata\x12\x0bTargetGroup\x82\xd3\xe4\x93\x02\x42\"=/apploadbalancer/v1/targetGroups/{target_group_id}:addTargets:\x01*\x12\xde\x01\n\rRemoveTargets\x12\x35.yandex.cloud.apploadbalancer.v1.RemoveTargetsRequest\x1a!.yandex.cloud.operation.Operation\"s\xb2\xd2*$\n\x15RemoveTargetsMetadata\x12\x0bTargetGroup\x82\xd3\xe4\x93\x02\x45\"@/apploadbalancer/v1/targetGroups/{target_group_id}:removeTargets:\x01*\x12\xde\x01\n\x0eListOperations\x12\x41.yandex.cloud.apploadbalancer.v1.ListTargetGroupOperationsRequest\x1a\x42.yandex.cloud.apploadbalancer.v1.ListTargetGroupOperationsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/apploadbalancer/v1/targetGroups/{target_group_id}/operationsBz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.apploadbalancer.v1.target_group_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer'
  _globals['_GETTARGETGROUPREQUEST'].fields_by_name['target_group_id']._loaded_options = None
  _globals['_GETTARGETGROUPREQUEST'].fields_by_name['target_group_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTTARGETGROUPSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTTARGETGROUPSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTTARGETGROUPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTTARGETGROUPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTTARGETGROUPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTTARGETGROUPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTTARGETGROUPSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTTARGETGROUPSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_DELETETARGETGROUPREQUEST'].fields_by_name['target_group_id']._loaded_options = None
  _globals['_DELETETARGETGROUPREQUEST'].fields_by_name['target_group_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATETARGETGROUPREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATETARGETGROUPREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATETARGETGROUPREQUEST'].fields_by_name['target_group_id']._loaded_options = None
  _globals['_UPDATETARGETGROUPREQUEST'].fields_by_name['target_group_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATETARGETGROUPREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATETARGETGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _globals['_UPDATETARGETGROUPREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATETARGETGROUPREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATETARGETGROUPREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATETARGETGROUPREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATETARGETGROUPREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATETARGETGROUPREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATETARGETGROUPREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATETARGETGROUPREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATETARGETGROUPREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATETARGETGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _globals['_CREATETARGETGROUPREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATETARGETGROUPREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATETARGETGROUPREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATETARGETGROUPREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_ADDTARGETSREQUEST'].fields_by_name['target_group_id']._loaded_options = None
  _globals['_ADDTARGETSREQUEST'].fields_by_name['target_group_id']._serialized_options = b'\350\3071\001'
  _globals['_ADDTARGETSREQUEST'].fields_by_name['targets']._loaded_options = None
  _globals['_ADDTARGETSREQUEST'].fields_by_name['targets']._serialized_options = b'\202\3101\002>0'
  _globals['_REMOVETARGETSREQUEST'].fields_by_name['target_group_id']._loaded_options = None
  _globals['_REMOVETARGETSREQUEST'].fields_by_name['target_group_id']._serialized_options = b'\350\3071\001'
  _globals['_REMOVETARGETSREQUEST'].fields_by_name['targets']._loaded_options = None
  _globals['_REMOVETARGETSREQUEST'].fields_by_name['targets']._serialized_options = b'\202\3101\002>0'
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST'].fields_by_name['target_group_id']._loaded_options = None
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST'].fields_by_name['target_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_TARGETGROUPSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_TARGETGROUPSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0024\0222/apploadbalancer/v1/targetGroups/{target_group_id}'
  _globals['_TARGETGROUPSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_TARGETGROUPSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\"\022 /apploadbalancer/v1/targetGroups'
  _globals['_TARGETGROUPSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_TARGETGROUPSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*(\n\031CreateTargetGroupMetadata\022\013TargetGroup\202\323\344\223\002%\" /apploadbalancer/v1/targetGroups:\001*'
  _globals['_TARGETGROUPSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_TARGETGROUPSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateTargetGroupMetadata\022\013TargetGroup\202\323\344\223\002722/apploadbalancer/v1/targetGroups/{target_group_id}:\001*'
  _globals['_TARGETGROUPSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_TARGETGROUPSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*2\n\031DeleteTargetGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\0024*2/apploadbalancer/v1/targetGroups/{target_group_id}'
  _globals['_TARGETGROUPSERVICE'].methods_by_name['AddTargets']._loaded_options = None
  _globals['_TARGETGROUPSERVICE'].methods_by_name['AddTargets']._serialized_options = b'\262\322*!\n\022AddTargetsMetadata\022\013TargetGroup\202\323\344\223\002B\"=/apploadbalancer/v1/targetGroups/{target_group_id}:addTargets:\001*'
  _globals['_TARGETGROUPSERVICE'].methods_by_name['RemoveTargets']._loaded_options = None
  _globals['_TARGETGROUPSERVICE'].methods_by_name['RemoveTargets']._serialized_options = b'\262\322*$\n\025RemoveTargetsMetadata\022\013TargetGroup\202\323\344\223\002E\"@/apploadbalancer/v1/targetGroups/{target_group_id}:removeTargets:\001*'
  _globals['_TARGETGROUPSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_TARGETGROUPSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002?\022=/apploadbalancer/v1/targetGroups/{target_group_id}/operations'
  _globals['_GETTARGETGROUPREQUEST']._serialized_start=316
  _globals['_GETTARGETGROUPREQUEST']._serialized_end=370
  _globals['_LISTTARGETGROUPSREQUEST']._serialized_start=373
  _globals['_LISTTARGETGROUPSREQUEST']._serialized_end=513
  _globals['_LISTTARGETGROUPSRESPONSE']._serialized_start=515
  _globals['_LISTTARGETGROUPSRESPONSE']._serialized_end=635
  _globals['_DELETETARGETGROUPREQUEST']._serialized_start=637
  _globals['_DELETETARGETGROUPREQUEST']._serialized_end=694
  _globals['_DELETETARGETGROUPMETADATA']._serialized_start=696
  _globals['_DELETETARGETGROUPMETADATA']._serialized_end=748
  _globals['_UPDATETARGETGROUPREQUEST']._serialized_start=751
  _globals['_UPDATETARGETGROUPREQUEST']._serialized_end=1205
  _globals['_UPDATETARGETGROUPREQUEST_LABELSENTRY']._serialized_start=1160
  _globals['_UPDATETARGETGROUPREQUEST_LABELSENTRY']._serialized_end=1205
  _globals['_UPDATETARGETGROUPMETADATA']._serialized_start=1207
  _globals['_UPDATETARGETGROUPMETADATA']._serialized_end=1259
  _globals['_CREATETARGETGROUPREQUEST']._serialized_start=1262
  _globals['_CREATETARGETGROUPREQUEST']._serialized_end=1661
  _globals['_CREATETARGETGROUPREQUEST_LABELSENTRY']._serialized_start=1160
  _globals['_CREATETARGETGROUPREQUEST_LABELSENTRY']._serialized_end=1205
  _globals['_CREATETARGETGROUPMETADATA']._serialized_start=1663
  _globals['_CREATETARGETGROUPMETADATA']._serialized_end=1715
  _globals['_ADDTARGETSREQUEST']._serialized_start=1717
  _globals['_ADDTARGETSREQUEST']._serialized_end=1833
  _globals['_ADDTARGETSMETADATA']._serialized_start=1835
  _globals['_ADDTARGETSMETADATA']._serialized_end=1880
  _globals['_REMOVETARGETSREQUEST']._serialized_start=1882
  _globals['_REMOVETARGETSREQUEST']._serialized_end=2001
  _globals['_REMOVETARGETSMETADATA']._serialized_start=2003
  _globals['_REMOVETARGETSMETADATA']._serialized_end=2051
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST']._serialized_start=2054
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST']._serialized_end=2189
  _globals['_LISTTARGETGROUPOPERATIONSRESPONSE']._serialized_start=2191
  _globals['_LISTTARGETGROUPOPERATIONSRESPONSE']._serialized_end=2306
  _globals['_TARGETGROUPSERVICE']._serialized_start=2309
  _globals['_TARGETGROUPSERVICE']._serialized_end=3955
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.searchapi.v2.search_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class WebSearchAsyncServiceStub:
    """A set of methods for async search the Yandex search database."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Search: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.search_service_pb2.WebSearchRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

class WebSearchAsyncServiceAsyncStub:
    """A set of methods for async search the Yandex search database."""

    Search: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.search_service_pb2.WebSearchRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

class WebSearchAsyncServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for async search the Yandex search database."""

    @abc.abstractmethod
    def Search(
        self,
        request: yandex.cloud.searchapi.v2.search_service_pb2.WebSearchRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

def add_WebSearchAsyncServiceServicer_to_server(servicer: WebSearchAsyncServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...

class WebSearchServiceStub:
    """A set of methods for searching the Yandex search database."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Search: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.search_service_pb2.WebSearchRequest,
        yandex.cloud.searchapi.v2.search_service_pb2.WebSearchResponse,
    ]

class WebSearchServiceAsyncStub:
    """A set of methods for searching the Yandex search database."""

    Search: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.search_service_pb2.WebSearchRequest,
        yandex.cloud.searchapi.v2.search_service_pb2.WebSearchResponse,
    ]

class WebSearchServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for searching the Yandex search database."""

    @abc.abstractmethod
    def Search(
        self,
        request: yandex.cloud.searchapi.v2.search_service_pb2.WebSearchRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.searchapi.v2.search_service_pb2.WebSearchResponse, collections.abc.Awaitable[yandex.cloud.searchapi.v2.search_service_pb2.WebSearchResponse]]: ...

def add_WebSearchServiceServicer_to_server(servicer: WebSearchServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
